==> ansela_0.5-2.tar.gz: ansela-0.5/src/opt/anselA/ui/temp.py <==
        
#        for x in range(255):
#            plotX =OrignX + x
#            sortCol=sorted(((x,plotList[x],"red"),(x+256,plotList[x+256],"green"),(x+512,plotList[x+512],"blue")), key=operator.itemgetter(1))
#            draw.line([plotX, OrignY, plotX, OrignY-sortCol[2][1]], fill=sortCol[2][2])
#            draw.line([plotX, OrignY, plotX, OrignY-sortCol[1][1]], fill=sortCol[1][2])
#            draw.line([plotX, OrignY, plotX, OrignY-sortCol[0][1]], fill=sortCol[0][2])
#        del draw 
            
            

#    if (soft == True):
#        if (value >0):
#            return 1+(math.exp(2-((99-value)*6/100)))
#        if (value <0):
#            return 1-((math.exp(2-((99+value)*6/100)))/8)
#        if (value ==0):
#            return 1
#    else:


#            w, h = im.size
#            draw = ImageDraw.Draw(im)
#            theta =math.radians(rotation)
#
#            cos = math.cos(theta)
#            sin = math.sin(theta)
#            W = w
#            H = h
#            h0 = (H*cos-W*sin)/(cos*cos-sin*sin)
#            w0 = (W-h0*sin)/cos
#
#            X = 0
#            Y = 0
#            x1 = abs(h0*sin)
#            y1 = abs(w0*sin)
#            x2 = abs(h0*sin)
#            y2 = abs(h0*cos)
#
#            #im=im.crop((int(x1), int(y1), int(x2), int(y2)))
#            draw.rectangle([int(x1), int(y1), int(x2), int(y2)])      
#            theta = math.radians(value)
#            #Calc Ops and Adjacent sides of triangle from Height.
#
#
#            h_new = h*abs(math.cos(theta)) + w*abs(math.sin(theta)) 
#            w_new = w*abs(math.cos(theta)) + h*abs(math.sin(theta))
#            self.lcdRot_1.setText(str(round(theta, 2)))
#            self.lcdRot_2.setText(str(round(value, 2)))
#            self.lcdRot_3.setText(str(round(h_new, 2)))
#            self.lcdRot_4.setText(str(round(w_new, 2)))
#
#            h_rec = round((h - (h * (h/h_new)))/2)
#            w_rec = round((w - (w * (w/w_new)))/2)
            

#            botOps = round(abs(h * math.sin(theta))/2)
#            botAdj = round(abs(h * math.cos(theta))/2)
#
#            topOps = round(abs(w * math.sin(theta))/2)
#            topAdj = round(abs(w * math.cos(theta))/2)
            
#            pi2 = math.pi/2
#            if( theta >= 0.0 and theta < pi2 ):
#                draw.rectangle([botOps,topOps, int(w-botOps),  int(h-topOps)]) 
#            elif( theta >= pi2 and theta < math.pi):
#                draw.rectangle([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
#            elif( theta >= math.pi and theta < (math.pi + pi2) ):
#                draw.rectangle([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
#            elif( theta >= (math.pi + pi2)):
#                draw.rectangle([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
#                    

#enhancer = ImageEnhance.Sharpness(image)

        #        for i in range(8):
        #            factor = i / 4.0
        #            enhancer.enhance(factor)
        #            


        # multiply each pixel by 1.2
        # out = im.point(lambda i: i * 1.2)
        # split the image into individual bands
        # select regions where red is less than 100
        # QtGui.QMessageBox.information(self, "Loading Data", "Please wait while the data is retrieved...")
        # self.refresh()
        # mask = source[R].point(lambda i: i < 100 and 255)
        # mask = source[G].point(lambda i: i < 100 and 255)
        # out = source[G].point(lambda i: i * 0.01*self.valG)
        # source[G].paste(out, None, mask)
        # mask = source[B].point(lambda i: i < 100 and 255)
        # out = source[B].point(lambda i: i * 0.01*self.valB)
        # source[B].paste(out, None, mask)
        # imout = im.point(lambda i: expression and 255)
    
    
    

        
        
        
        #e2 = "xyz.jpg"
        #im = Image.open(file2)
        #enhancer = ImageEnhance.Brightness(im)
        #bright_im = enhancer.enhance(0.5) #any value you want
        #sharp_im = bright_im.filter(ImageFilter.SHARPEN)
        #sharp_im.save("xyz1.jpg",quality=100)

        #im2 = im.filter(ImageFilter.MinFilter(3))
        #im2 = im.filter(ImageFilter.MinFilter(3))
        #im3 = im.filter(ImageFilter.MinFilter) # same as MinFilter(3)


        #Enhance(self, im, "Contrast", ImageEnhance.Contrast, -1.0, 3.0)
                    

        #Enhance(root, im, "Color", ImageEnhance.Color, 0.0, 4.0).pack()
        #Enhance(Toplevel(), im, "Sharpness", ImageEnhance.Sharpness, -2.0, 2.0).pack()
        #Enhance(Toplevel(), im, "Brightness", ImageEnhance.Brightness, -1.0, 3.0).pack()
        #Enhance(Toplevel(), im, "Contrast", ImageEnhance.Contrast, -1.0, 3.0).pack()


#cp -r  /home/user/MyDocs/code/svn/ansela/trunk/* /home/user/MyDocs/code/svn/ansela/packaging/anselA/src/opt/anselA/
    
    


#border-radius: 10px; padding: 1px;
#color: rgb(255, 255, 255);
#border-style:solid;
#border-width:1px;
#border-color:#CCCCFF;
#background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:0, y2:0, stop:0 rgba(49, 104, 49, 147), stop:0.468182 rgba(80, 178, 82, 140), stop:0.490909 rgba(160, 205, 164, 211));


#QTabBar::tab {border-top-left-radius: 4px; border-top-right-radius:4px;         padding: 1px;}
#QTabBar::tab:selected{margin-top:0px; border-color:#FFCC00;border-bottom-color:#000000;margin-left:2px;margin-right:2px;background:qlineargradient(spread:pad, x1:0, y1:1, x2:0, y2:0, stop:0 rgba(196, 196, 196, 255), stop:0.277273 rgba(239, 239, 239, 255), stop:0.740909 rgba(235, 235, 235, 255), stop:1 rgba(208, 208, 208, 255)); }
#QTabBar::tab:!selected{margin-top:4px; margin-left:1px;margin-right:1px;background: qlineargradient(spread:pad, x1:0, y1:1, x2:0, y2:0, stop:0 rgba(55, 55, 55, 255), stop:0.277273 rgba(132, 132, 132, 255), stop:0.740909 rgba(155, 155, 155, 255), stop:1 rgba(82, 82, 82, 255));}

==> ansela_0.5-4.tar.gz: ansela-0.5/src/opt/anselA/ui/temp.py <==
<<<<<<< .mine
=======
# Temporary file for previously coded
#                self.val.curThumb = Eim
#                self.val.curIm = Eim
#
#                out0=source[R].point(lambda i: i * 3)
#                source[R].paste(out0,  None,  None)
#                out1=source[G].point(lambda i: i * 0)
#                source[G].paste(out1,  None,  None)
#                out2=source[B].point(lambda i: i * 0)
#                source[B].paste(out2,  None,  None)
#                im=Image.merge("RGB", (out0 ,  source[G],  source[B] ))
#                out=source[R].point(lambda i: i * 1)
#                source[R].paste(out,  None,  None)
#                out=source[G].point(lambda i: i * 1.9)
#                source[G].paste(out,  None,  None)
#                out=source[B].point(lambda i: i * 1)
#                source[B].paste(out,  None,  None)
#                im=Image.merge("RGB", (source[R] ,  source[G],  source[B] ))
#                im=im.convert("L")
#                source[B].point(lambda i: i * 1.2)
#                source[G].point(lambda i: i * 1.2)
#                source[B].point(lambda i: i * 1.2)
#                source[R].point(lambda i: i +source[G].getpixel((0,0)) * .5)
#                source[B].point(lambda i: i +source[G].getpixel((0,0)) * .5)
#                source[R].point(lambda i: i +source[G].getpixel((0,0)) * .33)
#                source[B].point(lambda i: i +source[G].getpixel((0,0)) * .66)
#                source[R].point(lambda i: i * 1.66)
#                source[G].point(lambda i: i * 1.66)

#    221
                
#         icon2.addPixmap(im,  QtGui.QIcon.Normal, QtGui.QIcon.Off)
#         icon = QIcon(QPixmap.fromImage(ImageQt.ImageQt(im)))
#			item = QListWidgetItem(os.path.basename(url)[:20] + "...", self.pictureListWidget)
#			item.setStatusTip(url)
#			item.setIcon(icon)
            
            
#            Imitem = QtGui.QListWidgetItem(file.replace(".jpg", "")), self.listPhotos);
#            Imitem.setIcon(QtGui.QIcon(im))
#            self.listPhotos.addItem(Imitem)

            
            #im.save(file + ".thumbnail", "JPEG")
            #elf.val.curIm = Image.open(filename)

#            p = open(filename, "rb")
#            tags = EXIF.process_file(p)
#            self.listEXIFData.addItem


#        self.btnBug.anim=QtCore.QPropertyAnimation(self.btnBug.proxy, "opacity")
#        self.btnBug.anim.setDuration(200)
#        self.btnBug.anim.setStartValue(self.btnBug.proxy.opacity())
#        self.btnBug.anim.setEndValue(target)
#        self.btnBug.anim.start()
#        self.btnBug.anim.finished.connect(self.btnBug.anim.deleteLater)
#    
#        self.btnBug.anim.finished.connect(self.btnBug)
    
>>>>>>> .r186
        
#        for x in range(255):
#            plotX =OrignX + x
#            sortCol=sorted(((x,plotList[x],"red"),(x+256,plotList[x+256],"green"),(x+512,plotList[x+512],"blue")), key=operator.itemgetter(1))
#            draw.line([plotX, OrignY, plotX, OrignY-sortCol[2][1]], fill=sortCol[2][2])
#            draw.line([plotX, OrignY, plotX, OrignY-sortCol[1][1]], fill=sortCol[1][2])
#            draw.line([plotX, OrignY, plotX, OrignY-sortCol[0][1]], fill=sortCol[0][2])
#        del draw 
            
            

#    if (soft == True):
#        if (value >0):
#            return 1+(math.exp(2-((99-value)*6/100)))
#        if (value <0):
#            return 1-((math.exp(2-((99+value)*6/100)))/8)
#        if (value ==0):
#            return 1
#    else:


#            w, h = im.size
#            draw = ImageDraw.Draw(im)
#            theta =math.radians(rotation)
#
#            cos = math.cos(theta)
#            sin = math.sin(theta)
#            W = w
#            H = h
#            h0 = (H*cos-W*sin)/(cos*cos-sin*sin)
#            w0 = (W-h0*sin)/cos
#
#            X = 0
#            Y = 0
#            x1 = abs(h0*sin)
#            y1 = abs(w0*sin)
#            x2 = abs(h0*sin)
#            y2 = abs(h0*cos)
#
#            #im=im.crop((int(x1), int(y1), int(x2), int(y2)))
#            draw.rectangle([int(x1), int(y1), int(x2), int(y2)])      
#            theta = math.radians(value)
#            #Calc Ops and Adjacent sides of triangle from Height.
#
#
#            h_new = h*abs(math.cos(theta)) + w*abs(math.sin(theta)) 
#            w_new = w*abs(math.cos(theta)) + h*abs(math.sin(theta))
#            self.lcdRot_1.setText(str(round(theta, 2)))
#            self.lcdRot_2.setText(str(round(value, 2)))
#            self.lcdRot_3.setText(str(round(h_new, 2)))
#            self.lcdRot_4.setText(str(round(w_new, 2)))
#
#            h_rec = round((h - (h * (h/h_new)))/2)
#            w_rec = round((w - (w * (w/w_new)))/2)
            

#            botOps = round(abs(h * math.sin(theta))/2)
#            botAdj = round(abs(h * math.cos(theta))/2)
#
#            topOps = round(abs(w * math.sin(theta))/2)
#            topAdj = round(abs(w * math.cos(theta))/2)
            
#            pi2 = math.pi/2
#            if( theta >= 0.0 and theta < pi2 ):
#                draw.rectangle([botOps,topOps, int(w-botOps),  int(h-topOps)]) 
#            elif( theta >= pi2 and theta < math.pi):
#                draw.rectangle([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
#            elif( theta >= math.pi and theta < (math.pi + pi2) ):
#                draw.rectangle([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
#            elif( theta >= (math.pi + pi2)):
#                draw.rectangle([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
#                    

#enhancer = ImageEnhance.Sharpness(image)

        #        for i in range(8):
        #            factor = i / 4.0
        #            enhancer.enhance(factor)
        #            


        # multiply each pixel by 1.2
        # out = im.point(lambda i: i * 1.2)
        # split the image into individual bands
        # select regions where red is less than 100
        # QtGui.QMessageBox.information(self, "Loading Data", "Please wait while the data is retrieved...")
        # self.refresh()
        # mask = source[R].point(lambda i: i < 100 and 255)
        # mask = source[G].point(lambda i: i < 100 and 255)
        # out = source[G].point(lambda i: i * 0.01*self.valG)
        # source[G].paste(out, None, mask)
        # mask = source[B].point(lambda i: i < 100 and 255)
        # out = source[B].point(lambda i: i * 0.01*self.valB)
        # source[B].paste(out, None, mask)
        # imout = im.point(lambda i: expression and 255)
    
    
    

        
        
        
        #e2 = "xyz.jpg"
        #im = Image.open(file2)
        #enhancer = ImageEnhance.Brightness(im)
        #bright_im = enhancer.enhance(0.5) #any value you want
        #sharp_im = bright_im.filter(ImageFilter.SHARPEN)
        #sharp_im.save("xyz1.jpg",quality=100)

        #im2 = im.filter(ImageFilter.MinFilter(3))
        #im2 = im.filter(ImageFilter.MinFilter(3))
        #im3 = im.filter(ImageFilter.MinFilter) # same as MinFilter(3)


        #Enhance(self, im, "Contrast", ImageEnhance.Contrast, -1.0, 3.0)
                    

        #Enhance(root, im, "Color", ImageEnhance.Color, 0.0, 4.0).pack()
        #Enhance(Toplevel(), im, "Sharpness", ImageEnhance.Sharpness, -2.0, 2.0).pack()
        #Enhance(Toplevel(), im, "Brightness", ImageEnhance.Brightness, -1.0, 3.0).pack()
        #Enhance(Toplevel(), im, "Contrast", ImageEnhance.Contrast, -1.0, 3.0).pack()


#cp -r  /home/user/MyDocs/code/svn/ansela/trunk/* /home/user/MyDocs/code/svn/ansela/packaging/anselA/src/opt/anselA/
    
    


#border-radius: 10px; padding: 1px;
#color: rgb(255, 255, 255);
#border-style:solid;
#border-width:1px;
#border-color:#CCCCFF;
#background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:0, y2:0, stop:0 rgba(49, 104, 49, 147), stop:0.468182 rgba(80, 178, 82, 140), stop:0.490909 rgba(160, 205, 164, 211));


#QTabBar::tab {border-top-left-radius: 4px; border-top-right-radius:4px;         padding: 1px;}
#QTabBar::tab:selected{margin-top:0px; border-color:#FFCC00;border-bottom-color:#000000;margin-left:2px;margin-right:2px;background:qlineargradient(spread:pad, x1:0, y1:1, x2:0, y2:0, stop:0 rgba(196, 196, 196, 255), stop:0.277273 rgba(239, 239, 239, 255), stop:0.740909 rgba(235, 235, 235, 255), stop:1 rgba(208, 208, 208, 255)); }
#QTabBar::tab:!selected{margin-top:4px; margin-left:1px;margin-right:1px;background: qlineargradient(spread:pad, x1:0, y1:1, x2:0, y2:0, stop:0 rgba(55, 55, 55, 255), stop:0.277273 rgba(132, 132, 132, 255), stop:0.740909 rgba(155, 155, 155, 255), stop:1 rgba(82, 82, 82, 255));}
